// ************************* SIMPLE_TOONED.FRAG *************************

#version 330

struct Material {
	sampler2D diffuse;
	sampler2D specular;
	float shininess;
};

struct Light {
	vec3 position;
	vec3 ambient;
	vec3 diffuse;
	vec3 specular;
};

in vec2 TexCoords;
in vec3 Normal;
in vec3 FragPos;

layout(location = 0) out vec4 color;
layout(location = 1) out vec4 brightcolor;

uniform vec3 viewPos;
uniform Material material;
uniform Light light;


void main()
{
	// Ambient Light
	vec3 ambient = light.ambient * vec3(1.0 , 1.0, 0.0);
	//vec3(texture(material.diffuse, TexCoords));
	
	// Diffuse Light
	vec3 norm = normalize(Normal);
	vec3 lightDir = normalize(light.position - FragPos);
	float diff = max(dot(norm, lightDir), 0.0);
	if (diff > 0.95)
		diff = 1.0f;
	else if (diff > 0.50)
		diff = 0.6f;
	else if (diff > 0.25)
		diff = 0.4f;
	else
		diff = 0.2f;
	vec3 diffuse = light.diffuse * diff * vec3(1.0 , 1.0, 0.0);
	//vec3(texture(material.diffuse, TexCoords));

	// Specular Light
	// higher value means more concentrated highlight
	vec3 viewDir = normalize(viewPos - FragPos);
	vec3 reflectDir = reflect(-lightDir, norm);
	float spec = pow(max(dot(viewDir, reflectDir), 0.0), material.shininess);
	vec3 specular = light.specular * spec * vec3(1.0 , 1.0, 0.0);
	//vec3(texture(material.specular, TexCoords));

	vec3 result = ambient + diffuse + specular;
	color = vec4(result, 1.0f);

	// bright pass for bloom
	brightcolor = vec4(1.0f);
	brightcolor.r = max(color.r - 0.8f, 0.0f);
	brightcolor.g = max(color.g - 0.8f, 0.0f);
	brightcolor.b = max(color.b - 0.8f, 0.0f);
}